@@ -1,7 +1,7 @@
 use self::metadata::{Metadata, ParamMetadata};
 use super::{contains_decorator, DecoratorFinder};
 use smallvec::SmallVec;
-use std::mem::{replace, take};
+use std::mem::take;
 use swc_common::{collections::AHashMap, util::move_map::MoveMap, DUMMY_SP};
 use swc_ecma_ast::*;
 use swc_ecma_transforms_base::helper;
@@ -213,7 +213,7 @@ impl Fold for Legacy {
                 Stmt::Decl(Decl::Var(VarDecl {
                     span: DUMMY_SP,
                     kind: VarDeclKind::Var,
-                    decls: replace(&mut self.uninitialized_vars, Default::default()),
+                    decls: take(&mut self.uninitialized_vars),
                     declare: false,
                 })),
             );
@@ -255,7 +255,7 @@ impl Legacy {
                 buf.push(T::from_stmt(Stmt::Decl(Decl::Var(VarDecl {
                     span: DUMMY_SP,
                     kind: VarDeclKind::Var,
-                    decls: replace(&mut self.initialized_vars, Default::default()),
+                    decls: take(&mut self.initialized_vars),
                     declare: false,
                 }))));
             }
